==> haskell-tasty-quickcheck-0.10-16-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-tasty-quickcheck.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tasty-quickcheck
version: 0.10
id: tasty-quickcheck-0.10-K9hZ8OCyg3FA8FfaiByfLd
key: tasty-quickcheck-0.10-K9hZ8OCyg3FA8FfaiByfLd
license: MIT
maintainer: Roman Cheplyaka <roma@ro-che.info>
author: Roman Cheplyaka <roma@ro-che.info>
homepage: https://github.com/feuerbach/tasty
synopsis: QuickCheck support for the Tasty test framework.
description:
    QuickCheck support for the Tasty test framework.
category: Testing
abi: cba0c2161424b57698ca8b07a7bdf701
exposed: True
exposed-modules:
    Test.Tasty.QuickCheck
import-dirs: /usr/lib/ghc-8.4.3/site-local/tasty-quickcheck-0.10
library-dirs: /usr/lib/ghc-8.4.3/site-local/tasty-quickcheck-0.10
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/tasty-quickcheck-0.10
hs-libraries: HStasty-quickcheck-0.10-K9hZ8OCyg3FA8FfaiByfLd
depends:
    base-4.11.1.0 tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO
    tasty-1.1.0.3-47QwUInRtOzF3zSlr6CCJg
    random-1.1-9LLJAJa4iQFLJiLXBOBXBV
    QuickCheck-2.11.3-58QsvdIMmwDDNaUIIDmLAr
    optparse-applicative-0.14.2.0-AIlRv3oqRnL3QRzeNDiQLx
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO=92d44612a64675b8cba7ce44e507a395
             tasty-1.1.0.3-47QwUInRtOzF3zSlr6CCJg=2e6555b026876c59a316d2124bf273ef
             random-1.1-9LLJAJa4iQFLJiLXBOBXBV=2cade9e72fa19fe7a43e5ace84505d9f
             QuickCheck-2.11.3-58QsvdIMmwDDNaUIIDmLAr=59a035869ce3bae16d8c8360447f600f
             optparse-applicative-0.14.2.0-AIlRv3oqRnL3QRzeNDiQLx=122fe1d9115c41827cd61505838d2602
haddock-interfaces: /usr/share/doc/haskell-tasty-quickcheck/html/tasty-quickcheck.haddock
haddock-html: /usr/share/doc/haskell-tasty-quickcheck/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tasty-quickcheck-0.10-17-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-tasty-quickcheck.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tasty-quickcheck
version: 0.10
id: tasty-quickcheck-0.10-91UePWX8wtPAxf1UaCIKAS
key: tasty-quickcheck-0.10-91UePWX8wtPAxf1UaCIKAS
license: MIT
maintainer: Roman Cheplyaka <roma@ro-che.info>
author: Roman Cheplyaka <roma@ro-che.info>
homepage: https://github.com/feuerbach/tasty
synopsis: QuickCheck support for the Tasty test framework.
description:
    QuickCheck support for the Tasty test framework.
category: Testing
abi: a64ddf7f5ecef8a3b6d657510a11c03c
exposed: True
exposed-modules:
    Test.Tasty.QuickCheck
import-dirs: /usr/lib/ghc-8.4.3/site-local/tasty-quickcheck-0.10
library-dirs: /usr/lib/ghc-8.4.3/site-local/tasty-quickcheck-0.10
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/tasty-quickcheck-0.10
hs-libraries: HStasty-quickcheck-0.10-91UePWX8wtPAxf1UaCIKAS
depends:
    base-4.11.1.0 tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO
    tasty-1.1.0.3-KUFSSP3U4ny9AQF2XUXxIK
    random-1.1-9LLJAJa4iQFLJiLXBOBXBV
    QuickCheck-2.11.3-58QsvdIMmwDDNaUIIDmLAr
    optparse-applicative-0.14.2.0-5kDvpaFLtQNB16vTZLs8dg
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO=92d44612a64675b8cba7ce44e507a395
             tasty-1.1.0.3-KUFSSP3U4ny9AQF2XUXxIK=b3b38fe9dbf8881a7eed1fb4b5bf8074
             random-1.1-9LLJAJa4iQFLJiLXBOBXBV=2cade9e72fa19fe7a43e5ace84505d9f
             QuickCheck-2.11.3-58QsvdIMmwDDNaUIIDmLAr=59a035869ce3bae16d8c8360447f600f
             optparse-applicative-0.14.2.0-5kDvpaFLtQNB16vTZLs8dg=ae7f0ef22284c6d85efc629be435c88e
haddock-interfaces: /usr/share/doc/haskell-tasty-quickcheck/html/tasty-quickcheck.haddock
haddock-html: /usr/share/doc/haskell-tasty-quickcheck/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
